@@ -6,7 +6,7 @@ import json
 import re
 
 from urllib.parse import quote_plus
-from util import PlayStoreException, PlayStoreCollections
+from google_play_scraper.util import PlayStoreException, PlayStoreCollections
 
 
 class PlayStoreScraper:
@@ -225,6 +225,7 @@ class PlayStoreScraper:
 
 		try:
 			result = requests.get(url).text
+
 			pricing = json.loads(self.extract_json_block(result, "ds:3"))
 			info = json.loads(self.extract_json_block(result, "ds:5"))
 			version = json.loads(self.extract_json_block(result, "ds:8"))
@@ -242,8 +243,8 @@ class PlayStoreScraper:
 			"developer_link": self.PLAYSTORE_URL + info[0][12][5][5][4][2],
 			"developer_name": info[0][12][5][1],
 			"description": info[0][10][0][1],
-			"rating": rating[0][0][0][7][0][1],
-			"price_inapp": info[0][12][12][0],
+			"rating": rating[0][0][0][7][0][1] if rating[0][0][0][7] else 0,
+			"price_inapp": info[0][12][12][0] if info[0][12][12] else "",
 			"category": info[0][12][25],
 			"num_downloads": info[0][12][9][2],
 			"num_downloads_approx": info[0][12][9][1],
@@ -286,7 +287,7 @@ class PlayStoreScraper:
 		:param str block_id: ID of the block, e.g. 'ds:3'
 		:return str:  JSON (unparsed) for that block ID
 		"""
-		prefix = re.compile(r"AF_init[dD]ata[cC]all[bB]ack\s*\({[^{}]*key:\s*'" + re.escape(block_id) + "'[^{}]+data:")
+		prefix = re.compile(r"AF_init[dD]ata[cC]all[bB]ack\s*\({[^{}]*key:\s*'" + re.escape(block_id) + ".*?data:")
 		suffix = re.compile(r"}\s*\)\s*;")
 
 		block = prefix.split(html)[1]
